@@ -1,4 +1,4 @@
-use MY::slurp;
+use File::Slurp qw(slurp);
 use File::Spec::Functions qw(catfile);
 my $r = shift;
 $r->content_type('text/javascript');
